@@ -1,4 +1,4 @@
-;; notmuch-query.el --- provide an emacs api to query notmuch
+;;; notmuch-query.el --- provide an emacs api to query notmuch
 ;;
 ;; Copyright © David Bremner
 ;;
@@ -15,10 +15,12 @@
 ;; General Public License for more details.
 ;;
 ;; You should have received a copy of the GNU General Public License
-;; along with Notmuch.  If not, see <http://www.gnu.org/licenses/>.
+;; along with Notmuch.  If not, see <https://www.gnu.org/licenses/>.
 ;;
 ;; Authors: David Bremner <david@tethera.net>
 
+;;; Code:
+
 (require 'notmuch-lib)
 
 (defun notmuch-query-get-threads (search-terms)
@@ -28,9 +30,9 @@ A thread is a forest or list of trees. A tree is a two element
 list where the first element is a message, and the second element
 is a possibly empty forest of replies.
 "
-  (let ((args '("show" "--format=sexp" "--format-version=1")))
+  (let ((args '("show" "--format=sexp" "--format-version=4")))
     (if notmuch-show-process-crypto
-	(setq args (append args '("--decrypt"))))
+	(setq args (append args '("--decrypt=true"))))
     (setq args (append args search-terms))
     (apply #'notmuch-call-notmuch-sexp args)))
 
@@ -74,3 +76,5 @@ See the function notmuch-query-get-threads for more information."
    (notmuch-query-get-threads search-terms)))
 
 (provide 'notmuch-query)
+
+;;; notmuch-query.el ends here
